<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2013 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =====================
	// settings.php - French
	// =====================

	// Français formel (Vous)
	// This language file was translated by Jürgen Schäfer, 2010; ==> http://www.minetoshsoft.com
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

	// general settings
	$charset = "utf-8";
	$language = "Français (Vous) / French (formal)";
	$language_short = "fr";
	$language_version = "1.5.1";
	$language_timezone = "Europe/Paris";
	$language_author = "J&uuml;rgen Sch&auml;fer";
?>
